Documentation
¶
Overview ¶
A library for working with blocks of the Parallelcoin DUO token ledger
Index ¶
- Constants
- type Block
- type CoinStats
- type CoinsView
- type CoinsViewBacked
- type CoinsViewCache
- type CoinsViewMemPool
- type Contents
- type DiskIndex
- type FileInfo
- type Header
- type Index
- type Locator
- type MerkleBlock
- type MerkleTx
- type PartialMerkleTree
- type ScriptCheck
- type Template
- type Undo
- type ValidationState
Constants ¶
const ( // ModeValid means a block is valid ModeValid = iota // ModeInvalid means a block is invalid ModeInvalid // ModeError means there was an error in the block ModeError )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CoinStats ¶
type CoinStats struct {
Height int
HashBlock Uint.U256
Txs, TxOutputs, SerializedSize uint64
HashSerialized Uint.U256
TotalAmount uint64
}
CoinStats stores the current state of the currency
type CoinsViewBacked ¶
type CoinsViewBacked struct {
// contains filtered or unexported fields
}
CoinsViewBacked is
type CoinsViewCache ¶
CoinsViewCache is
type FileInfo ¶
type FileInfo struct {
Blocks, Size, UndoSize, HeightFirst, HeightLast uint
TimeFirst, TimeLast uint64
}
FileInfo stores details about the blockchain on disk
type Index ¶
type Index struct {
HashBlock Uint.U256
Prev *Index
Height, File int
DataPos, UndoPos uint
ChainWork Uint.U256
TxCount, TxCumulative, Status uint
Version int
HashMerkleRoot Uint.U256
Time, Bits, Nonce uint
}
var ( // ChainIndex is a centralised index of a server's chain ChainIndex Index )
type MerkleTx ¶
type MerkleTx struct {
tx.Transaction
HashBlock Uint.U256
MerkleBranch []*Uint.U256
Index int
Verified bool
}
MerkleTx is
type PartialMerkleTree ¶
PartialMerkleTree is
type ScriptCheck ¶
type ScriptCheck struct {
ScriptPubKey tx.Script
To tx.Transaction
In, Flags, HashType uint
}
ScriptCheck tracks the verification of scripts
type ValidationState ¶
ValidationState stores the state of validation of a block
Click to show internal directories.
Click to hide internal directories.